@@ -20,10 +20,13 @@
 
   // Check that we have a reasonable size.
   if (xsize <= 0 || ysize <= 0)
-    [InvalidCombination raiseEvent: "SugarSpace was created with an invalid size\n"];
+    [InvalidCombination raiseEvent:
+                          "SugarSpace was created with an invalid size\n"];
   // and a datafile
   if (maxSugarDataFile == NULL)
-    [InvalidCombination raiseEvent: "SugarSpace was created without a data file for max sugar.\n"];
+    [InvalidCombination
+      raiseEvent:
+        "SugarSpace was created without a data file for max sugar.\n"];
 
   // Create the array to represent the sugar itself.
   sugar = [Discrete2d createBegin: [self getZone]];
